"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getUsage = void 0;
const ejs_1 = require("ejs");
const path_1 = require("path");
const fs_1 = require("fs");
const utils_1 = require("@knapsack/utils");
const file_utils_1 = require("@knapsack/file-utils");
const renderUsageTemplate = (0, ejs_1.compile)((0, fs_1.readFileSync)((0, path_1.join)(__dirname, '../template.vue.ejs'), 'utf8'), {
    filename: 'template.vue.ejs',
    async: true,
});
/**
 * Return the stringified output needed within Usage blocks
 */
async function getUsage(data) {
    // Convert object to array of key-value pairs
    const props = Object.entries(data.props || {}).map(([key, value]) => ({
        // `subTitle` => `sub-title`
        // @link https://vuejs.org/guide/essentials/component-basics.html#dom-template-parsing-caveats
        key: (0, utils_1.kebabCase)(key),
        value,
    }));
    const attributes = props
        .map(({ key, value }) => {
        switch (typeof value) {
            case 'string':
                return `${key}="${value}"`;
            // For `case 'boolean'`, see default.
            // @link https://vuejs.org/guide/components/props.html#boolean
            // For `case 'object'` (which covers arrays), see default
            // @link https://vuejs.org/guide/components/props.html#array
            // Handles all cases where the prop value is "runtime javascript":
            // 1. Stringified
            // 2. Within single quotes to allow for double quotes in `value`
            // 3. Use the v-bind Vue attribute (ie :thing)
            default:
                return `:${key}='${JSON.stringify(value)}'`;
        }
    })
        .filter(Boolean)
        .join(' ');
    const { templateName, children, before, after } = data;
    const result = await renderUsageTemplate({
        templateName,
        attributes,
        props,
        children,
        before,
        after,
    });
    const code = await (0, file_utils_1.formatCode)({
        contents: result,
        // Note: this is converting double quotes from our prop values to single
        // quotes, making EVERYTHING WORK. Prettier is effectively cleaning up
        // JSON.stringify() here.
        path: `${templateName}.vue`,
    });
    return code.trim();
}
exports.getUsage = getUsage;
//# sourceMappingURL=utils.js.map